#ifdef luaL_openlibs
FOREACH_LUA_FUNCTION(luaL_openselectedlibs)
#else
FOREACH_LUA_FUNCTION(luaL_openlibs)
#endif
FOREACH_LUA_FUNCTION(luaL_requiref)
#ifdef lua_newuserdata
FOREACH_LUA_FUNCTION(lua_newuserdatauv)
#else
FOREACH_LUA_FUNCTION(lua_newuserdata)
#endif
FOREACH_LUA_FUNCTION(lua_setglobal)
FOREACH_LUA_FUNCTION(luaL_loadfilex)
FOREACH_LUA_FUNCTION(lua_pcallk)
FOREACH_LUA_FUNCTION(lua_gettop)
FOREACH_LUA_FUNCTION(lua_tolstring)
FOREACH_LUA_FUNCTION(lua_getglobal)
FOREACH_LUA_FUNCTION(lua_pushinteger)
FOREACH_LUA_FUNCTION(lua_pushboolean)
FOREACH_LUA_FUNCTION(lua_toboolean)
FOREACH_LUA_FUNCTION(lua_settop)
FOREACH_LUA_FUNCTION(lua_pushstring)
FOREACH_LUA_FUNCTION(lua_pushlstring)
FOREACH_LUA_FUNCTION(lua_type)
FOREACH_LUA_FUNCTION(lua_gettable)
FOREACH_LUA_FUNCTION(lua_tointegerx)
FOREACH_LUA_FUNCTION(lua_pushnil)
FOREACH_LUA_FUNCTION(lua_next)
FOREACH_LUA_FUNCTION(lua_rawlen)
FOREACH_LUA_FUNCTION(luaL_len)
FOREACH_LUA_FUNCTION(lua_createtable)
FOREACH_LUA_FUNCTION(lua_rawset)
FOREACH_LUA_FUNCTION(luaL_checkversion_)
FOREACH_LUA_FUNCTION(luaL_setfuncs)
FOREACH_LUA_FUNCTION(luaL_loadstring)
FOREACH_LUA_FUNCTION(luaL_checkinteger)
FOREACH_LUA_FUNCTION(luaL_checklstring)
FOREACH_LUA_FUNCTION(lua_rawseti)
